@@ -15,11 +15,11 @@ RPM::Packager - Manifest-based approach for building RPMs
 
 =head1 VERSION
 
-Version 0.3.1
+Version 0.3.2
 
 =cut
 
-our $VERSION = 'v0.3.1';
+our $VERSION = 'v0.3.2';
 
 =head1 SYNOPSIS
 
@@ -42,7 +42,7 @@ simple as writing a YAML file that looks like the following:
     sign:                               # optionally, gpg signing of RPM
       gpg_name: ED16CAB                 # provide the GPG key ID
       passphrase_cmd: cat secret_file   # command to retrieve the secret
-    after_install: /path/to/script      # script to run after the package is installed (%post)
+    after_install: path/to/script       # shellscript to run after the package is installed (%post)
 
 Then run:
 
